@@ -72,7 +72,8 @@ def fetch(request):
             return JsonResponse(conf.entity_configuration_as_dict, safe=False)
         else:
             return HttpResponse(
-                conf.entity_configuration_as_jws, content_type="application/entity-statement+jwt"
+                conf.entity_configuration_as_jws, 
+                content_type="application/entity-statement+jwt"
             )
 
     sub = FederationDescendant.objects.filter(
@@ -263,7 +264,7 @@ def resolve_entity_statement(request, format: str = "jose"):
         return JsonResponse(res, safe=False)
     else:
         return HttpResponse(
-            create_jws(res, iss.jwks[0]),
+            create_jws(res, iss.jwks_fed[0]),
             content_type="application/jose",
         )
 
