@@ -39,7 +39,7 @@ class OidcUserInfo(object):
                 jwe = authz_userinfo.content.decode()
                 header = unpad_jwt_head(jwe)
                 # header["kid"] kid di rp
-                rp_jwk = self.get_jwk(header["kid"], self.rp_conf.jwks)
+                rp_jwk = self.get_jwk(header["kid"], self.rp_conf.jwks_core)
                 jws = decrypt_jwe(jwe, rp_jwk)
 
                 header = unpad_jwt_head(jws)
